pub struct Geometry<'a> {
pub vertices: &'a [[f32; 3]],
pub faces: &'a [[usize; 3]],
pub colors: &'a [Rgb565],
pub lines: &'a [[usize; 2]],
pub normals: &'a [[f32; 3]],
pub vertex_normals: &'a [[f32; 3]],
pub uvs: &'a [[f32; 2]],
pub texture_id: Option<u32>,
}Fields
vertices: &'a [[f32; 3]]faces: &'a [[usize; 3]]colors: &'a [Rgb565]lines: &'a [[usize; 2]]normals: &'a [[f32; 3]]vertex_normals: &'a [[f32; 3]]Per-vertex normals for smooth (Gouraud) shading.
If non-empty, must have the same length as vertices.
uvs: &'a [[f32; 2]]UV texture coordinates (one per vertex)
texture_id: Option<u32>Optional texture ID for this geometry
Implementations
Sourceimpl Geometry<'_>
impl Geometry<'_>
Sourcepub fn lines_from_faces<const N: usize>(
faces: &[[usize; 3]],
) -> Vec<(usize, usize), N>
pub fn lines_from_faces<const N: usize>( faces: &[[usize; 3]], ) -> Vec<(usize, usize), N>
Converts faces to unique edge pairs for line rendering.
Type Parameters
N- Maximum capacity for the edges buffer. For a closed mesh, a good estimate isfaces.len() * 3 / 2since each edge is typically shared by 2 faces.
Returns
A heapless Vec containing unique edge pairs. If capacity is exceeded, returns partial results with an error logged.