pub struct PerformanceCounter { /* private fields */ }Expand description
Performance counter for measuring rendering performance
Timing Requirements:
This module requires the perfcounter feature and a timing source:
- For embedded with Embassy: enable both
perfcounterandembassy-timefeatures - For desktop/simulator: enable
stdfeature (includes perfcounter automatically) - Without a timing source, timing will always return 0
Example
# For embedded with Embassy:
embedded-3dgfx = { version = "0.1", features = ["perfcounter", "embassy-time"] }
# For desktop/simulator:
embedded-3dgfx = { version = "0.1", features = ["std"] }
# Pure no_std without perfcounter:
embedded-3dgfx = { version = "0.1", default-features = false }Implementations
Sourceimpl PerformanceCounter
impl PerformanceCounter
pub fn new() -> Self
pub fn only_fps(&mut self, only_fps: bool)
pub fn get_frametime(&self) -> u64
pub fn start_of_frame(&mut self)
pub fn add_measurement(&mut self, label: &str)
pub fn discard_measurement(&mut self)
pub fn print(&mut self)
pub fn get_text(&self) -> &str