pub enum Collider {
Sphere {
radius: f32,
},
Aabb {
half_extents: Vector3<f32>,
},
Capsule {
height: f32,
radius: f32,
},
}Expand description
A collision shape attached to a RigidBody.
The collider is centered on the body’s position. For AABBs the half-extents define the box dimensions along each axis from the center.
Variants
Sphere
A sphere defined by its radius.
Aabb
An axis-aligned bounding box defined by half-extents along each axis.
Capsule
A capsule defined by height and radius. The capsule is oriented along the Y axis, centered on the body position. Height is the distance between the two hemisphere centers (excluding the caps).