pub struct FixedTimestep { /* private fields */ }Expand description
Accumulator for fixed-timestep game / physics loops (e.g. 50 Hz or 60 Hz).
Decouples erratic render framerates from deterministic fixed update steps, avoiding physics instability on microcontrollers with variable SPI display scanout times.
Implementations
Sourceimpl FixedTimestep
impl FixedTimestep
Sourcepub const fn from_hz(hz: f32, max_substeps: u32) -> Self
pub const fn from_hz(hz: f32, max_substeps: u32) -> Self
Create a fixed timestep with a given step duration (e.g. 1.0 / 60.0)
and a maximum number of substeps per tick (e.g. 4) to prevent spiral-of-death.
Sourcepub const fn from_step(step: f32, max_substeps: u32) -> Self
pub const fn from_step(step: f32, max_substeps: u32) -> Self
Create from step delta in seconds.
Sourcepub fn update(&mut self, frame_dt: f32) -> FixedStepIter ⓘ
pub fn update(&mut self, frame_dt: f32) -> FixedStepIter ⓘ
Feed frame delta-time frame_dt and return an iterator of fixed timesteps to simulate.