pub unsafe trait DMACapableFrameBufferBackend: FrameBufferBackend {
// Required method
fn data_ptr(&self) -> *const Self::Color;
}Expand description
Backends implementing this Trait can be used for DMA.
Safety
The same restrictions as for embedded_dma::ReadBuffer apply.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
Sourceimpl<'a, C, const N: usize> DMACapableFrameBufferBackend for &'a mut [C; N]where
C: PixelColor,
Safety:
The implementation of the trait for all lifetimes 'a is safe. However,
this doesn’t mean that the use of it is safe for all lifetimes. The
requirements specified in embedded_dma::ReadBuffer::read_buffer remain.
impl<'a, C, const N: usize> DMACapableFrameBufferBackend for &'a mut [C; N]where
C: PixelColor,
Safety:
The implementation of the trait for all lifetimes 'a is safe. However,
this doesn’t mean that the use of it is safe for all lifetimes. The
requirements specified in embedded_dma::ReadBuffer::read_buffer remain.