Crate embedded_3dgfx

Crate embedded_3dgfx 

Re-exports

pub use draw::ReadPixel;
pub use bridge::AsEgPoint;
pub use bridge::AsNalgebraPoint;
pub use bridge::draw_to;
pub use bridge::eg_to_nalgebra;
pub use bridge::nalgebra_to_eg;
pub use bridge::render_drawable_to_buffer;
pub use renderer::DirtyRegion;
pub use renderer::FrameCtx;
pub use tilebin::TileBinStats;
pub use tilebin::TileConfig;
pub use transform_anim::AnimationPlayer;
pub use transform_anim::SampledTransform;
pub use transform_anim::TransformKeyframe;
pub use transform_anim::TransformTrack;
pub use tween::Easing;
pub use tween::Tween;
pub use tween::Tween3;
pub use tween::apply_easing;
pub use tween::lerp;
pub use tween::lerp3;
pub use tween::scale_rgb565;

Modules

animation
Vertex Animation System
billboard
Billboard rendering for sprites that always face the camera
bridge
Interoperability bridges between embedded-3dgfx and embedded-graphics.
camera
command_buffer
config
display_backend
Display backend abstraction for DMA-based rendering
draw
error
fixed_math
hardware_profile
hud
lut
Lookup tables for fast trigonometric operations
mesh
painters
Painter’s Algorithm Implementation
perfcounter
physics
Physics engine for embedded 3D graphics.
renderer
scene_format
scene_stream
skeleton
Skeletal animation system with subspace deformation (skinning).
softbody
Soft body physics using mass-spring systems and position-based dynamics.
swapchain
Swap chain implementation for double-buffered rendering
telemetry
texture
Texture mapping support for embedded 3D graphics
tilebin
transform_anim
Keyframed rigid-body transform animation (position, euler rotation, scale).
tween
Time-based interpolation and easing for boot sequences and UI motion.

Structs

BudgetFallbackOutcome
DegradationOutcome
EndianCorrectedBuffer
A backend for FrameBuf which changes the underlying byte order. This can be useful when using the buffer for DMA with peripherals that have a different endianness than the host.
FrameBuf
Constructs a frame buffer in memory. Lets you define the width(X), height (Y) and pixel type your using in your display (RGB, Monochrome etc.)
K3dengine
MeshRayCastHit
Result of a ray cast against triangle geometry.

Enums

DrawPrimitive
EndianCorrection
Enum indicating how the bytes should be converted in the host’s memory.

Traits

DMACapableFrameBufferBackend
Backends implementing this Trait can be used for DMA.

Functions

mesh_ray_cast
Ray-cast against triangle geometry using Möller–Trumbore intersection.