Skip to main content Crate embedded_3dgfx Copy item path Source pub use draw::ReadPixel ;animation Vertex Animation System billboard Billboard rendering for sprites that always face the camera camera display_backend Display backend abstraction for DMA-based rendering draw lut Lookup tables for fast trigonometric operations mesh painters Painter’s Algorithm Implementation perfcounter physics Physics engine for embedded 3D graphics. skeleton Skeletal animation system with subspace deformation (skinning). softbody Soft body physics using mass-spring systems and position-based dynamics. swapchain Swap chain implementation for double-buffered rendering texture Texture mapping support for embedded 3D graphics EndianCorrectedBuffer A backend for FrameBuf which changes the underlying
byte order. This can be useful when using the buffer for DMA with
peripherals that have a different endianness than the host. FrameBuf Constructs a frame buffer in memory. Lets you define the width(X), height
(Y) and pixel type your using in your display (RGB, Monochrome etc.) K3dengine DrawPrimitive EndianCorrection Enum indicating how the bytes should be converted in the host’s memory. DMACapableFrameBufferBackend Backends implementing this Trait can be used for DMA.