pub struct K3dMesh<'a> {
pub similarity: Similarity3<f32>,
pub model_matrix: Matrix4<f32>,
pub color: Rgb565,
pub render_mode: RenderMode,
pub geometry: Geometry<'a>,
pub lod_medium: Option<Geometry<'a>>,
pub lod_low: Option<Geometry<'a>>,
pub lod_levels: LODLevels,
pub priority: u8,
pub outline_color: Option<Rgb565>,
pub outline_width: f32,
}Expand description
A mesh with optional Level of Detail (LOD) support
Fields
similarity: Similarity3<f32>model_matrix: Matrix4<f32>color: Rgb565render_mode: RenderModegeometry: Geometry<'a>lod_medium: Option<Geometry<'a>>Optional LOD geometries (medium detail, low detail) If None, only the main geometry is used
lod_low: Option<Geometry<'a>>lod_levels: LODLevelspriority: u8outline_color: Option<Rgb565>outline_width: f32Implementations
Sourceimpl<'a> K3dMesh<'a>
impl<'a> K3dMesh<'a>
pub fn new(geometry: Geometry<'_>) -> K3dMesh<'_>
Sourcepub fn set_lod<'b>(
&mut self,
medium: Option<Geometry<'b>>,
low: Option<Geometry<'b>>,
levels: LODLevels,
)where
'b: 'a,
pub fn set_lod<'b>(
&mut self,
medium: Option<Geometry<'b>>,
low: Option<Geometry<'b>>,
levels: LODLevels,
)where
'b: 'a,
Set LOD geometries for this mesh
Arguments
medium- Medium detail geometry (optional)low- Low detail geometry (optional)levels- Distance thresholds for switching LOD levels
Sourcepub fn select_lod(&self, distance: f32) -> &Geometry<'_>
pub fn select_lod(&self, distance: f32) -> &Geometry<'_>
Select the appropriate geometry based on distance from camera
pub fn set_color(&mut self, color: Rgb565)
pub fn set_render_mode(&mut self, mode: RenderMode)
pub fn set_priority(&mut self, priority: u8)
pub fn set_position(&mut self, x: f32, y: f32, z: f32)
pub fn get_position(&self) -> Point3<f32>
pub fn set_attitude(&mut self, roll: f32, pitch: f32, yaw: f32)
Sourcepub fn set_rotation(&mut self, rotation: UnitQuaternion<f32>)
pub fn set_rotation(&mut self, rotation: UnitQuaternion<f32>)
Set orientation directly from a unit quaternion.
pub fn set_target(&mut self, target: Point3<f32>)
pub fn set_scale(&mut self, s: f32)
Sourcepub fn compute_bounding_radius_sq(&self) -> f32
pub fn compute_bounding_radius_sq(&self) -> f32
Compute the squared bounding sphere radius of the mesh in world-ish scale (model-space radius × uniform scale²).
With aabb-cull, uses the cached AABB when present (tighter than
origin-centered verts).