pub struct Timer { /* private fields */ }Expand description
A timer that tracks duration, progress fraction, completion, and repetition.
Implementations
Sourceimpl Timer
impl Timer
Sourcepub const fn from_seconds(duration: f32, mode: TimerMode) -> Self
pub const fn from_seconds(duration: f32, mode: TimerMode) -> Self
Create a new timer with a duration in seconds and a TimerMode.
Sourcepub fn new(duration: Duration, mode: TimerMode) -> Self
pub fn new(duration: Duration, mode: TimerMode) -> Self
Create a new timer from a core::time::Duration.
Sourcepub fn tick(&mut self, dt: f32) -> &mut Self
pub fn tick(&mut self, dt: f32) -> &mut Self
Advance the timer by dt seconds and evaluate completion.
Sourcepub fn tick_duration(&mut self, duration: Duration) -> &mut Self
pub fn tick_duration(&mut self, duration: Duration) -> &mut Self
Advance the timer by a core::time::Duration.
Sourcepub fn is_finished(&self) -> bool
pub fn is_finished(&self) -> bool
true if the timer is finished (or reached its target during this tick).
Sourcepub fn just_finished(&self) -> bool
pub fn just_finished(&self) -> bool
true only on the tick when the timer crossed or reached its duration.
Sourcepub fn remaining_secs(&self) -> f32
pub fn remaining_secs(&self) -> f32
Remaining duration in seconds until completion.
Sourcepub fn elapsed_secs(&self) -> f32
pub fn elapsed_secs(&self) -> f32
Elapsed time in seconds.
Sourcepub fn duration_secs(&self) -> f32
pub fn duration_secs(&self) -> f32
Total target duration in seconds.